@@ -20,5 +20,5 @@ class GroupFactory(factory.django.DjangoModelFactory):
             for member in extracted:
                 self.members.add(member)
         else:
-            for i in range(1, random.randrange(2, 10)):
+            for _ in range(1, random.randrange(2, 10)):
                 self.members.add(EntryFactory())
