@@ -210,11 +210,9 @@ class MicrosoftGraphAPI:
         return data
 
     def get_tenant_id(self, email: str) -> str | None:
-        try:
+        with suppress(Exception):
             if msuser := self.user(email):
                 return msuser.get("id", None)
-        except Exception:
-            pass
         return None
 
     def delta_changes_events(self, tenant_id: str, minutes: int) -> list:
@@ -428,11 +426,11 @@ class MicrosoftGraphAPI:
             global_preferences = global_preferences_registry.manager()
             headers["Authorization"] = f'Bearer {global_preferences["wbactivity_sync__outlook_sync_access_token"]}'
         if method == "POST":
-            response = requests.post(url, data=data, headers=headers)
+            response = requests.post(url, data=data, headers=headers, timeout=10)
         elif method == "DELETE":
-            response = requests.delete(url, headers=headers)
+            response = requests.delete(url, headers=headers, timeout=10)
         elif method == "PATCH":
-            response = requests.patch(url, data=data, headers=headers)
+            response = requests.patch(url, data=data, headers=headers, timeout=10)
         else:
-            response = requests.get(url, headers=headers, params=params)
+            response = requests.get(url, headers=headers, params=params, timeout=10)
         return response
