@@ -5,7 +5,7 @@ from django.contrib.messages import storage
 from rest_framework.test import APIRequestFactory
 
 
-class msgraph_fixture:
+class MSGraphFixture:
     token = None
     _subscriptions = []
     _subscription = None
