@@ -1,5 +1,6 @@
 from contextlib import suppress
 
+from django.conf import settings
 from dynamic_preferences.exceptions import NotFoundInRegistry
 from dynamic_preferences.registries import global_preferences_registry
 from wbcore.utils.importlib import import_from_dotted_path
@@ -8,7 +9,8 @@ from wbcore.utils.importlib import import_from_dotted_path
 def get_backend():
     from wbcrm.synchronization.activity.controller import ActivityController
 
-    with suppress(NotFoundInRegistry):
-        if backend := global_preferences_registry.manager()["wbactivity_sync__sync_backend_calendar"]:
-            backend = import_from_dotted_path(backend)
-            return ActivityController(backend=backend)
+    if not settings.DEBUG:
+        with suppress(NotFoundInRegistry):
+            if backend := global_preferences_registry.manager()["wbactivity_sync__sync_backend_calendar"]:
+                backend = import_from_dotted_path(backend)
+                return ActivityController(backend=backend)
