@@ -20,7 +20,7 @@ def merge_nested_dict(dct: dict, nested_to_merge: dict):
     """
     allows to merge 2 nested dictionaries
     """
-    for k, v in nested_to_merge.items():
+    for k in nested_to_merge.keys():
         if k in dct:
             if isinstance(dct[k], dict) and isinstance(nested_to_merge[k], dict):  # noqa
                 merge_nested_dict(dct[k], nested_to_merge[k])
